/**
 * The contents of this file are subject to the terms
 * of the Common Development and Distribution License
 * (the License). You may not use this file except in
 * compliance with the License.
 * 
 * You can obtain a copy of the license at
 * https://woodstock.dev.java.net/public/CDDLv1.0.html.
 * See the License for the specific language governing
 * permissions and limitations under the License.
 * 
 * When distributing Covered Code, include this CDDL
 * Header Notice in each file and include the License file
 * at https://woodstock.dev.java.net/public/CDDLv1.0.html.
 * If applicable, add the following below the CDDL Header,
 * with the fields enclosed by brackets [] replaced by
 * you own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
 */

/**
 * This optional variable contains config properties to initialize the 
 * environment. For example:
 * <p><code><pre>
 *
 * woodstock4_3Config = {
 *   // Ajax config properties.
 *   ajax: {
 *       // Flag allowing Ajax resources to be loaded in page.
 *       isAjax: false,
 *       // Flag allowing JSF Extensions to be loaded in page.
 *       isJsfx: true,
 *       // Ajax module.
 *       module: "woodstock4_3.widget._jsfx"
 *   },
 *   // Flag to enable debug mode.
 *   isDebug: false,
 *   // Woodstock module path.
 *   modulePath: "/example/resources/@JS_NS/suntheme/javascript",
 *   // Flag to inlcude style sheet(s).
 *   isStyleSheet: true,
 *   // Flag to parse HTML markup onLoad.
 *   parseOnLoad: true,
 *   // Custom name space to map as woodstock4_3.
 *   namespace: "webui.suntheme",
 *   // Theme config properties.
 *   theme: {
 *       // Theme bundle name.
 *       bundle: "suntheme",
 *       // An array of custom theme config properties.
 *       custom: [{
 *           /** Custom theme bundle name.
 *           bundle: "myTheme",
 *           /** Custom theme module path.
 *           modulePath: "/example/resources/custom"
 *       }],
 *       // Theme locale.
 *       locale: "en",
 *       // Theme module path.
 *       modulePath: "/example/resources/woodstock4_3/suntheme/javascript/theme",
 *       // App context.
 *       prefix: "/example/resources"
 *   },
 *   // Flag to include all widgets.
 *   webuiAll: false,
 *   // Flag to include Ajax functionality based on JSF Extensions.
 *   webuiJsfx: false
 * };
 *
 * </pre></code></p>
 * @name woodstock4_3Config
 */

// Initialize the woodstock4_3Config variable.
if (typeof woodstock4_3Config == "undefined") {
    this.woodstock4_3Config = {};
}

/**
 * @class This class contains config properties to initialize the environment.
 * Properties shall be ovrridden by the global woodstock4_3Config variable.
 * @static
 * @private
 */
woodstock4_3._base.config = {
    /** Ajax config properties. */
    ajax: {
        /** Flag allowing Ajax resources to be loaded in page. */
        isAjax: (woodstock4_3Config.ajax && woodstock4_3Config.ajax.isAjax != null)
            ? woodstock4_3Config.ajax.isAjax : false,
        /** Flag allowing JSF Extensions to be loaded in page. */
        isJsfx: (woodstock4_3Config.ajax && woodstock4_3Config.ajax.isJsfx != null)
            ? woodstock4_3Config.ajax.isJsfx : true,
        /** Ajax module. */
        module: (woodstock4_3Config.ajax && woodstock4_3Config.ajax.module)
            ? woodstock4_3Config.ajax.module : "woodstock4_3.widget._jsfx"
    },
    /** Flag to enable debug mode. */
    isDebug: (woodstock4_3Config.isDebug != null) ? woodstock4_3Config.isDebug : false,
    /** Flag to enable high contrast mode. */
    _isHighContrastMode: undefined,
    /** Dojo config properties. */
    _djConfig: {
        /** Dojo module path. */
        baseUrl: undefined,
        /** Flag to enable dojo debug mode. */
        isDebug: false
    },
    /** Woodstock module path. */
    modulePath: (woodstock4_3Config.modulePath) ? woodstock4_3Config.modulePath : undefined,
    /** Flag to inlcude style sheet(s). */
    isStyleSheet: (woodstock4_3Config.isStyleSheet != null) ? woodstock4_3Config.isStyleSheet : true,
    /** Flag to parse HTML markup onLoad. */
    parseOnLoad: (woodstock4_3Config.parseOnLoad != null) ? woodstock4_3Config.parseOnLoad : true,
    /** Custom name space to map as woodstock4_3. */
    namespace: (woodstock4_3Config.namespace) ? woodstock4_3Config.namespace : "webui.suntheme",
    /** Theme config properties. */
    theme: {
        /** Theme bundle name. */
        bundle: (woodstock4_3Config.theme && woodstock4_3Config.theme.bundle)
            ? woodstock4_3Config.theme.bundle : "suntheme",
        /** An array of custom theme config properties. See woodstock4_3Config. */
        custom: (woodstock4_3Config.theme && woodstock4_3Config.theme.custom)
            ? woodstock4_3Config.theme.custom : undefined,
        /** Theme locale. */
        locale: (woodstock4_3Config.theme && woodstock4_3Config.theme.locale)
            ? woodstock4_3Config.theme.locale : "en",
        /** Theme module path. */
        modulePath: (woodstock4_3Config.theme && woodstock4_3Config.theme.modulePath)
            ? woodstock4_3Config.theme.modulePath : undefined,
        /** App context. */
        prefix: (woodstock4_3Config.theme && woodstock4_3Config.theme.prefix)
            ? woodstock4_3Config.theme.prefix : undefined
    },
    /** Flag to include all widgets. */
    webuiAll: (woodstock4_3Config.webuiAll != null) ? woodstock4_3Config.webuiAll : false,
    /** Flag to include Ajax functionality based on JSF Extensions. */
    webuiJsfx: (woodstock4_3Config.webuiJsfx != null) ? woodstock4_3Config.webuiJsfx : false
};
